@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2008 William Jon McCann <jmccann@redhat.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -185,7 +186,9 @@ setup_dialog (GsmAppDialog *dialog)
         GError     *error;
 
         xml = gtk_builder_new ();
+#ifdef ENABLE_NLS
         gtk_builder_set_translation_domain (xml, GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
         error = NULL;
         if (!gtk_builder_add_from_file (xml,
