@@ -2,6 +2,7 @@
  * main.c
  * Copyright (C) 1999 Free Software Foundation, Inc.
  * Copyright (C) 2008 Lucas Rocha.
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -68,13 +69,15 @@ int main(int argc, char* argv[])
 	GError* error;
 	GtkWidget* dialog;
 
+#ifdef ENABLE_NLS
 	bindtextdomain(GETTEXT_PACKAGE, LOCALE_DIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
 	error = NULL;
 
-	if (!gtk_init_with_args(&argc, &argv, " - MATE Session Properties", options, GETTEXT_PACKAGE, &error))
+	if (!gtk_init_with_args(&argc, &argv, _("- MATE Session Properties"), options, GETTEXT_PACKAGE, &error))
 	{
 		g_warning("Unable to start: %s", error->message);
 		g_error_free(error);
