@@ -3,6 +3,7 @@
  * Copyright (C) 2007 Novell, Inc.
  * Copyright (C) 2008 Red Hat, Inc.
  * Copyright (C) 2008 William Jon McCann <jmccann@redhat.com>
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -509,9 +510,9 @@ update_iceauthority (GsmXsmpServer *server,
         }
 
         for (e = entries; e; e = e->next) {
-                IceAuthFileEntry *auth_entry = e->data;
-                IceWriteAuthFileEntry (fp, auth_entry);
-                IceFreeAuthFileEntry (auth_entry);
+                IceAuthFileEntry *auth_file_entry = e->data;
+                IceWriteAuthFileEntry (fp, auth_file_entry);
+                IceFreeAuthFileEntry (auth_file_entry);
         }
         g_slist_free (entries);
 
