@@ -2,6 +2,7 @@
  *
  * Copyright (C) 2006 Novell, Inc.
  * Copyright (C) 2008 Red Hat, Inc.
+ * Copyright (C) 2012-2021 MATE Developers
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -21,7 +22,6 @@
 
 #include <config.h>
 
-#include <libintl.h>
 #include <signal.h>
 #include <stdlib.h>
 #include <string.h>
@@ -622,9 +622,11 @@ int main(int argc, char** argv)
 		gsm_util_init_error(TRUE, "%s", error->message);
 	}
 
+#ifdef ENABLE_NLS
 	bindtextdomain(GETTEXT_PACKAGE, LOCALE_DIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
 	sa.sa_handler = SIG_IGN;
 	sa.sa_flags = 0;
