@@ -3,6 +3,7 @@
 
    Copyright (C) 1998 Tom Tromey
    Copyright (C) 2008 Red Hat, Inc.
+ * Copyright (C) 2012-2021 MATE Developers
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -206,9 +207,11 @@ int main(int argc, char* argv[])
 	int conflicting_options;
 
 	/* Initialize the i18n stuff */
+#ifdef ENABLE_NLS
 	bindtextdomain(GETTEXT_PACKAGE, LOCALE_DIR);
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	textdomain(GETTEXT_PACKAGE);
+#endif /* ENABLE_NLS */
 
 	error = NULL;
 
